==> peer-exchange-0.4.0.tgz: package/lib/transports.js <==
'use strict';

var http = require('http');
var getBrowserRTC = require('get-browser-rtc');
var SimplePeer = require('simple-peer');
var Websocket = require('websocket-stream');
try {
  var net = require('net');
} catch (err) {}

function webrtc(opts) {
  var wrtc = opts.wrtc || getBrowserRTC();

  function createPeer(opts, relay, cb) {
    opts = Object.assign({ wrtc: wrtc }, opts);
    var peer = new SimplePeer(opts);
    relay.on('data', function (data) {
      return peer.signal(data);
    });
    peer.on('signal', function (data) {
      return relay.write(data);
    });
    peer.on('error', function (err) {
      return cb(err);
    });
    peer.on('connect', function () {
      return cb(null, peer);
    });
  }

  function connect(address, opts, relay, cb) {
    createPeer({ initiator: true }, relay, cb);
  }

  function onIncoming(relay, cb) {
    createPeer({}, relay, cb);
  }

  return { connect: connect, onIncoming: onIncoming };
}

var websocket = {
  connect: function connect(address, opts, relay, cb) {
    var protocol = opts.secure ? 'wss' : 'ws';
    var ws = Websocket(protocol + '://' + address + ':' + opts.port);
    ws.on('error', function (err) {
      return cb(err);
    });
    cb(null, ws);
  },

  accept: function accept(opts, onConnection, cb) {
    // TODO: option for already-created http(s) server
    if (!opts.port) {
      throw new Error('Must specify "port" option');
    }
    var server = http.createServer();
    server.on('error', cb);
    server.listen(opts.port, function () {
      var wss = Websocket.createServer({ server: server }, onConnection);
      wss.on('error', cb);
      cb(null, server.close.bind(server));
    });
  }
};

var tcp = {
  connect: function connect(address, opts, relay, cb) {
    var socket = net.connect(opts.port, address, function () {
      return cb(null, socket);
    });
    socket.on('error', function (err) {
      return cb(err);
    });
  },

  accept: function accept(opts, onConnection, cb) {
    // TODO: option for already-created TCP server
    if (!opts.port) {
      throw new Error('Must specify "port" option');
    }
    var server = net.createServer(onConnection);
    server.on('error', cb);
    server.listen(opts.port, function () {
      cb(null, server.close.bind(server));
    });
  }
};

module.exports = { webrtc: webrtc, websocket: websocket, tcp: tcp };

==> peer-exchange-0.5.1.tgz: package/lib/transports.js <==
'use strict';

var http = require('http');
var https = require('https');
var getBrowserRTC = require('get-browser-rtc');
var SimplePeer = require('simple-peer');
var Websocket = require('websocket-stream');
try {
  var net = require('net');
} catch (err) {}

function webrtc(opts) {
  var wrtc = opts.wrtc || getBrowserRTC();

  function createPeer(opts, relay, cb) {
    opts = Object.assign({ wrtc: wrtc }, opts);
    var peer = new SimplePeer(opts);
    relay.on('data', function (data) {
      return peer.signal(data);
    });
    peer.on('signal', function (data) {
      return relay.write(data);
    });
    peer.on('error', function (err) {
      return cb(err);
    });
    peer.on('connect', function () {
      return cb(null, peer);
    });
  }

  function connect(address, opts, relay, cb) {
    createPeer({ initiator: true }, relay, cb);
  }

  function onIncoming(relay, cb) {
    createPeer({}, relay, cb);
  }

  return { connect: connect, onIncoming: onIncoming };
}

var websocket = {
  connect: function connect(address, opts, relay, cb) {
    var protocol = opts.secure ? 'wss' : 'ws';
    var ws = Websocket(protocol + '://' + address + ':' + opts.port);
    ws.on('error', function (err) {
      return cb(err);
    });
    cb(null, ws);
  },

  accept: function accept(opts, onConnection, cb) {
    if (!opts.port) {
      throw new Error('Must specify "port" option');
    }
    var httpsOpts;
    if (opts.https) {
      httpsOpts = opts.https;
      delete opts.https;
      opts.secure = true;
    }
    var server = httpsOpts ? https.createServer(httpsOpts) : http.createServer();
    server.on('error', cb);
    server.listen(opts.port, function () {
      var wss = Websocket.createServer({ server: server }, onConnection);
      wss.on('error', cb);
      cb(null, server.close.bind(server));
    });
  }
};

var tcp = {
  connect: function connect(address, opts, relay, cb) {
    var socket = net.connect(opts.port, address, function () {
      return cb(null, socket);
    });
    socket.on('error', function (err) {
      return cb(err);
    });
  },

  accept: function accept(opts, onConnection, cb) {
    // TODO: option for already-created TCP server
    if (!opts.port) {
      throw new Error('Must specify "port" option');
    }
    var server = net.createServer(onConnection);
    server.on('error', cb);
    server.listen(opts.port, function () {
      cb(null, server.close.bind(server));
    });
  }
};

module.exports = { webrtc: webrtc, websocket: websocket, tcp: tcp };
